==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/autoresponder/translations/autoresponder_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Jen poprvé</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Odpovědět do porad</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Stav neviditelný</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Stav zaneprázdněn</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Dostupný</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Samočinný odpovídač</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Text pro automatickou odpověď</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Vybrat stav</translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>AUTOMATICKÁ ODPOVĚĎ KADU:</translation>
    </message>
    <message>
        <source>I am busy.</source>
        <translation>Jsem zaneprázdněn.</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/autoresponder/translations/autoresponder_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Jen poprvé</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Odpovědět do porad</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Stav neviditelný</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Stav zaneprázdněn</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Dostupný</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Samočinný odpovídač</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Text pro automatickou odpověď</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Vybrat stav</translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>AUTOMATICKÁ ODPOVĚĎ KADU:</translation>
    </message>
    <message>
        <source>I am busy.</source>
        <translation>Jsem zaneprázdněn.</translation>
    </message>
</context>
</TS>
